![icon.drawio.png](misc/artwork/icon_name.drawio.png)

-----------------------------------------------------------

## Description
A container build manager.

## Documentation
Run:
```commandline
cd docs/build/html
python3 -m http.server 8080
```
And then go to <http://localhost:8080>.

## Installation
``` commandline
pip install olcf-velocity
alias velocity="python3 -m velocity"
```
